@@ -33,10 +33,10 @@ def pack():
 )
 @click.option("-p", "--password", "password", help="Password for user in Njinn API.")
 @click.option("-a", "--api", "api", help="Njinn API url.")
-@click.option("-n", "--namespace", "namespace", help="Namespace for pack installation.")
-def install(repository_url, branch, username, password, api, namespace):
+@click.option("--global", "global_", is_flag=True, help="Whether to install a pack globally. Works only with superuser permissions.")
+def install(repository_url, branch, username, password, api, global_):
     logger.info("Installing pack from %s" % repository_url)
-    pack_install(repository_url, branch, username, password, api, namespace)
+    pack_install(repository_url, branch, username, password, api, global_)
 
 
 if __name__ == "__main__":
